<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Issue extends CI_Controller {

	public function __construct() {
		parent::__construct();
		date_default_timezone_set("Asia/Kolkata");
		$this->load->model('Issue_model');

		if(!$this->session->userdata('logged_in')) {
			redirect(base_url());
		}
	}

	public function addIssue(){
		$template['page'] = 'Issue/issueForm';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'Add Issue';
        $template['pTitle'] = "Add Issue";
        $template['pDescription'] = "Create New Issue";

        $template['issue_data'] = $this->Issue_model->getIssue();
		$this->load->view('template',$template);
	}

	public function viewIssues(){
		$template['page'] = 'Issue/viewIssues';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'View Issues';
        $template['pTitle'] = "View Issues";
        $template['pDescription'] = "View and Manage Issues";

        $template['issue_data'] = $this->Issue_model->getIssue('',1);
		$this->load->view('template',$template);
	}

	function changeStatus($issue_id = '',$status = '1'){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !is_numeric($issue_id = decode_param($issue_id))){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewIssues'));
		}
		$status = $this->Issue_model->changeStatus($issue_id,$status);
		if(!$status){
			$this->session->set_flashdata('message',$flashMsg);
		}
		redirect(base_url('Issue/viewIssues'));
	}

	public function createIssue(){
		$err = 0;
		$errMsg = '';
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(!isset($_POST) || empty($_POST)){
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/addIssue'));
		}
		if($err == 0 && (!isset($_POST['issue']) || empty($_POST['issue']))){
			$err = 1;
			$errMsg = 'Provide Issue Short Discription';
		}

		if($err == 1){
			$flashMsg['message'] = $errMsg;
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/addIssue'));
		}

        $status = $this->Issue_model->addIssue($_POST);
        if($status == 1){
            $flashMsg =array('message'=>'Successfully Updated Issue Details..!','class'=>'success');
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/viewIssues'));
        } else {
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/addIssue'));
        }
	}

	public function editIssue($issue_id = ''){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !is_numeric($issue_id = decode_param($issue_id))){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewIssues'));
		}

		$template['page'] = 'Issue/issueForm';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'Edit Issue';
        $template['pTitle'] = "Edit Issue";
        $template['pDescription'] = "Update Issue Data";

        $template['issue_id'] = encode_param($issue_id);
        $template['issue_data'] = $this->Issue_model->getIssue($issue_id,1);
		if(empty($template['issue_data'])){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewIssues'));
		}
		$this->load->view('template',$template);
	}

	public function updateIssue($issue_id = ''){
		$err = 0;
		$errMsg = '';
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !isset($_POST) || empty($_POST) || !is_numeric(decode_param($issue_id))){
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/viewIssues'));
		}
		if(!isset($_POST) || empty($_POST)){
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/addIssue'));
		}
		if($err == 0 && (!isset($_POST['issue']) || empty($_POST['issue']))){
			$err = 1;
			$errMsg = 'Provide a Issue Short Discription';
		}

		if($err == 1){
			$flashMsg['message'] = $errMsg;
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/addIssue'));
		}

        $status = $this->Issue_model->updateIssue(decode_param($issue_id),$_POST);
        if($status == 1){
            $flashMsg =array('message'=>'Successfully Updated Issue Details..!','class'=>'success');
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/viewIssues'));
        } else {
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/editIssue/'.$issue_id));
        }
	}

	public function issueMapping(){
		if($this->session->userdata('user_type') == 1){
			redirect(base_url('Issue/viewIssues'));
		}

		$template['page'] = 'Issue/issueMapping';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'Issue Mapping';
        $template['pTitle'] = "Issue Mapping";
        $template['pDescription'] = "Creating Couston Issues";

        $template['issue_data'] = $this->Issue_model->getIssue('',1);
        $template['mechanic_id'] = encode_param($this->session->userdata('id'));
        if(empty($template['issue_data'])){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewIssues'));
		}
		$this->load->view('template',$template);
	}

	public function createMechIssue(){
		$err = 0;
		$errMsg = '';
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(!isset($_POST) || empty($_POST) || !isset($_POST['mechanic_id']) || 
		   empty(($_POST['mechanic_id'])) || 
		   !is_numeric($_POST['mechanic_id'] = decode_param($_POST['mechanic_id']))){
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/issueMapping'));
		}
		if($err == 0 && (!isset($_POST['issue_id']) || empty($_POST['issue_id']))){
			$err = 1;
			$errMsg = 'Choose as Issue';
		} 
		else if($err == 0 && (!isset($_POST['service_fee']) || empty($_POST['service_fee']))){
			$err = 1;
			$errMsg = 'Provide a Service Cost';
		} 
		else if($err == 0 && (!isset($_POST['issue_description']) || empty($_POST['issue_description']))){
			$err = 1;
			$errMsg = 'Provide a Brief Discription About Service';
		} 
		
		if($err == 1){
			$flashMsg['message'] = $errMsg;
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Issue/issueMapping'));
		}

        $status = $this->Issue_model->addMechIssue($_POST);
        if($status == 1){
            $flashMsg =array('message'=>'Successfully Created..!','class'=>'success');
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/viewMappedIssues'));
        } else {
            $this->session->set_flashdata('message', $flashMsg);
            redirect(base_url('Issue/issueMapping'));
        }
	}

 	function viewMappedIssues($mechanic_id = ''){
 		if(isset($_POST['mechanic_id']) && !empty($_POST['mechanic_id'])){
 			$mechanic_id = $_POST['mechanic_id'];
 		}
 		$mechanic_id = (!is_numeric($mechanic_id = decode_param($mechanic_id)))?'':$mechanic_id;

		$template['page'] = 'Issue/viewMappedIssues';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'Manage Mapped Issues';
        $template['pTitle'] = "Manage Mapped Issues";
        $template['pDescription'] = "View and Manage Mapped Issues";
        $template['mechanic_data'] = '';
 		if($this->session->userdata('user_type') == 1){
			$this->load->model('Mechanic_model');
			$template['mechanic_data'] = $this->Mechanic_model->getMechanic('',1);
 		} else {
 			$mechanic_id = $this->session->userdata('id');
 		}
 		
 		$template['mechanicIssueData'] = $this->Issue_model->getMechanicIssues($mechanic_id);
 		$template['mechanic_id'] = $mechanic_id;
		$this->load->view('template',$template);
 	}

 	function changeMappedIssueStatus($mechanic_id = '',$issue_id = '',$status = '1'){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !is_numeric($issue_id  = decode_param($issue_id)) || 
		   empty($mechanic_id) || !is_numeric($mechanic_id  = decode_param($mechanic_id))){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewMappedIssues/'.encode_param($mechanic_id)));
		}
		$status = $this->Issue_model->changeMappedIssueStatus($mechanic_id,$issue_id,$status);
		if(!$status){
			$this->session->set_flashdata('message',$flashMsg);
		}
		redirect(base_url('Issue/viewMappedIssues/'.encode_param($mechanic_id)));
 	}


	public function editMechanicIssues($mechanic_id = '',$issue_id = ''){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !is_numeric($issue_id = decode_param($issue_id)) || 
		   empty($mechanic_id) || !is_numeric($mechanic_id = decode_param($mechanic_id))){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewMappedIssues'));
		}

		$template['page'] = 'Issue/issueMapping';
        $template['menu'] = 'Issue Management';
        $template['smenu'] = 'Edit Mechanic Issue';
        $template['pTitle'] = "Edit Mechanic Issue Management";
        $template['pDescription'] = "Update Custom Mechanic Issue Data";

        $template['issue_id'] = $issue_id;
        $template['mechanic_id'] = $mechanic_id;
        $template['issue_data'] = $this->Issue_model->getIssue('',1);
 		$template['mechanicIssueData'] = $this->Issue_model->getMechanicIssues($mechanic_id,$issue_id);
		if(empty($template['mechanicIssueData'])){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewMappedIssues/'.encode_param($mechanic_id)));
		}
		$this->load->view('template',$template);
	}

	public function updateMechIssue($mechanic_id = '',$issue_id = ''){
		$err = 0;
		$errMsg = '';
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($issue_id) || !is_numeric($issue_id = decode_param($issue_id)) || 
		   empty($mechanic_id) || !is_numeric($mechanic_id = decode_param($mechanic_id))){
			$this->session->set_flashdata('message',$flashMsg);
        	redirect(base_url('Issue/viewMappedIssues/'.encode_param($mechanic_id)));
		}
		$url = base_url('Issue/editMechanicIssues/'.encode_param($mechanic_id).'/'.encode_param($issue_id));
		if(!isset($_POST) || empty($_POST)){
			$this->session->set_flashdata('message',$flashMsg);
            redirect($url);
		}
		if($err == 0 && (!isset($_POST['issue_id']) || empty($_POST['issue_id']))){
			$err = 1;
			$errMsg = 'Choose as Issue';
		} 
		else if($err == 0 && (!isset($_POST['service_fee']) || empty($_POST['service_fee']))){
			$err = 1;
			$errMsg = 'Provide a Service Cost';
		} 
		else if($err == 0 && (!isset($_POST['issue_description']) || empty($_POST['issue_description']))){
			$err = 1;
			$errMsg = 'Provide a Brief Discription About Service';
		} 
		
		if($err == 1){
			$flashMsg['message'] = $errMsg;
			$this->session->set_flashdata('message',$flashMsg);
            redirect($url);
		}

        $status = $this->Issue_model->updateMechIssue($mechanic_id,$issue_id,$_POST);
        if($status == 1){
            $flashMsg =array('message'=>'Successfully Updated..!','class'=>'success');
            $this->session->set_flashdata('message', $flashMsg);
        	redirect(base_url('Issue/viewMappedIssues/'.encode_param($mechanic_id)));
        } else {
            $this->session->set_flashdata('message', $flashMsg);
            redirect($url);
        }
	}
}
?>